@@ -1,6 +1,6 @@
 #' @title **NHL Game Content**
 #' @description Returns game content for a given game ID
-#' @param game_id Game unique ID 
+#' @param game_id Game unique ID
 #' @return Returns a tibble
 #' @keywords NHL Game Content
 #' @import rvest
@@ -10,32 +10,33 @@
 #' @importFrom tidyr unnest unnest_wider everything
 #' @importFrom janitor clean_names
 #' @export
-#' @examples 
+#' @examples
 #' \donttest{
-#'   nhl_game_content(game_id=2021020182)
+#'    try(nhl_game_content(game_id=2021020182))
 #' }
 nhl_game_content <- function(game_id){
-  
+
   base_url <- "https://statsapi.web.nhl.com/api/v1/game/"
-  
-  full_url <- paste0(base_url, 
+
+  full_url <- paste0(base_url,
                      game_id,
                      "/content")
-  
-  
+
+
   res <- httr::RETRY("GET", full_url)
-  
+
   # Check the result
   check_status(res)
-  
-  resp <- res %>%
-    httr::content(as = "text", encoding = "UTF-8")
+
   tryCatch(
     expr = {
+      resp <- res %>%
+        httr::content(as = "text", encoding = "UTF-8")
       game_highlights_df <- jsonlite::fromJSON(resp)[["highlights"]]
       game_highlights_df <- game_highlights_df$gameCenter
       game_highlights_df <- game_highlights_df$items
-      
+      game_highlights_df <- game_highlights_df %>%
+        make_fastRhockey_data("NHL Game Content Information from NHL.com",Sys.time())
     },
     error = function(e) {
       message(glue::glue("{Sys.time()}: Invalid arguments or no game content data for {game_id} available!"))
@@ -46,4 +47,4 @@ nhl_game_content <- function(game_id){
     }
   )
   return(game_highlights_df)
-}
\ No newline at end of file
+}
